@@ -8,7 +8,7 @@ use Class::Utils qw(set_params split_params);
 use Error::Pure qw(err);
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub _cleanup {
 	my $self = shift;
@@ -52,7 +52,7 @@ sub _process {
 			['d', @{$self->{'_a'}->data}],
 		);
 	} elsif ($self->{'_a'}->data_type eq 'tags') {
-		$self->{'tags'}->put($self->{'_a'}->data);
+		$self->{'tags'}->put(@{$self->{'_a'}->data});
 	}
 	$self->{'tags'}->put(
 		['e', 'a'],
@@ -271,6 +271,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
